@@ -2,7 +2,7 @@ from requests import Session, Response
 from typing import Callable, Union
 
 from ..structs import IGProfile, State, DeviceProfile, Method
-from .structs.profile import ProfileSetGender, ProfileSetBiography, ProfileUpdate
+from .structs.profile import ProfileSetGender, ProfileSetBiography, ProfileUpdate, ProfileInfo
 
 
 class ProfileMixin:
@@ -53,3 +53,11 @@ class ProfileMixin:
     def profile_update(self, obj: ProfileUpdate):
         """Updates the name, username, email, phone number and url for the currently logged in user."""
         self._profile_act(obj)
+
+    def profile_info(self, obj: ProfileInfo) -> Response:
+        if obj.user_id is None:
+            obj.user_id = self.state.user_id
+        data = self._request(f'users/{obj.user_id}/info/').json()
+        if data['status'] == 'ok':
+            return data['users']
+        return data['status']
